==> mshow-model-1.0.0.0-20190126.083137-37-sources.jar: com/mini/mshow/model/dbto/site/SubjectActivityDbto.java <==
package com.mini.mshow.model.dbto.site;

import java.util.Date;

import com.mini.framework.model.dbto.style1.DbtoIntEntity;
import com.mini.framework.model.role.write.Insertable;
import com.mini.framework.model.role.write.Updatable;
import com.mini.mshow.model.dbto.able.HaveActivity;
import com.mini.mshow.model.dbto.able.HaveAuthor;
import com.mini.mshow.model.dbto.able.IsOneSubject;
import com.mini.mshow.model.dto.multi.MultiFactory;
import com.mini.mshow.model.type.SubjectType;

public class SubjectActivityDbto extends DbtoIntEntity implements HaveActivity,HaveAuthor,IsOneSubject{

	/**
	 * 
	 */
	private static final long serialVersionUID = 6149160031081726843L;

	
	public SubjectOverviewDbto tryFindOverview(){
		boolean right = MultiFactory.validate(mutliContent);
		if(right){
			SubjectOverviewDbto overview = SubjectOverviewDbto.findOverview(MultiFactory.fromJson(mutliContent));
			overview.setTitle(title);
			overview.setSubTitle(subTitle);
			// TODO 如果活动有封面应该弄去上
			return overview;
		}
		return null;
	}
	
	public void fillFixField(SubjectOverviewDbto overview){
		if(overview!=null){
			overview.setSubjectAuthorId(authorId);
			overview.setSubjectId(getId());
			overview.setSubjectType(SubjectType.activity);
		}
	}
	
	
	/**
	 * 标题
	 */
	@Insertable(require="活动标题",minLength=2,maxLength=30)
	@Updatable(suffice="活动标题",minLength=2,maxLength=30)
	private String title;

	/**
	 * 活动子标题
	 */
	@Updatable(suffice="活动子标题",minLength=5)
	private String subTitle;

	/**
	 * 复杂的内容
	 */
	@Insertable(require="活动多媒体")
	@Updatable(suffice="活动多媒体")
	private String mutliContent;
	
	/**
	 * 作者的用户 id
	 */
	@Insertable(require="活动作者")
	@Updatable(forbid="活动作者")
	private Integer authorId;
	
	
	/**
	 * 原创的key，标记这个东西是谁
	 * 这个东西用于在复制的时候记录是谁原创的
	 */
	@Insertable(require="原始作者")
	@Updatable(forbid="原始作者")
	private Integer originalAuthorId;
	
	
	/**
	 * 开始时间
	 */
	@Insertable(require="开始时间")
	@Updatable(suffice="开始时间")
	private Date beginDate;
	

	/**
	 * 结束时间
	 */
	@Insertable(require="结束时间")
	@Updatable(suffice="结束时间")
	private Date endDate;
	
	
	/**
	 * 地址名字
	 */
	@Insertable(require="地址名字")
	@Updatable(suffice="地址名字")
	private String addressName;
	

	/**
	 * 地址GPS
	 * 用户短横线隔开
	 * 经度-纬度
	 */
	@Updatable(suffice="地址GPS")
	private String addressGps;
	
	
	/**
	 * 主办方
	 */
	@Insertable(require="主办方")
	@Updatable(suffice="主办方")
	private String presider;
	
	
	public String getTitle() {
		return title;
	}

	public void setTitle(String title) {
		this.title = title;
	}

	public String getMutliContent() {
		return mutliContent;
	}

	public void setMutliContent(String mutliContent) {
		this.mutliContent = mutliContent;
	}

	public String getSubTitle() {
		return subTitle;
	}

	public void setSubTitle(String subTitle) {
		this.subTitle = subTitle;
	}

	public Integer getAuthorId() {
		return authorId;
	}

	public void setAuthorId(Integer authorId) {
		this.authorId = authorId;
	}


	public Integer getOriginalAuthorId() {
		return originalAuthorId;
	}


	public void setOriginalAuthorId(Integer originalAuthorId) {
		this.originalAuthorId = originalAuthorId;
	}
	
	

	public Date getBeginDate() {
		return beginDate;
	}

	public void setBeginDate(Date beginDate) {
		this.beginDate = beginDate;
	}

	public Date getEndDate() {
		return endDate;
	}

	public void setEndDate(Date endDate) {
		this.endDate = endDate;
	}

	public String getAddressName() {
		return addressName;
	}

	public void setAddressName(String addressName) {
		this.addressName = addressName;
	}

	public String getAddressGps() {
		return addressGps;
	}

	public void setAddressGps(String addressGps) {
		this.addressGps = addressGps;
	}

	public String getPresider() {
		return presider;
	}

	public void setPresider(String presider) {
		this.presider = presider;
	}

	@Override
	public Integer showActivityId() {
		return getId();
	}

	@Override
	public Integer showAuthorId() {
		return authorId;
	}

	@Override
	public SubjectType showSubectType() {
		return SubjectType.activity;
	}

	@Override
	public Integer showSubjectId() {
		return getId();
	}
	

}

==> mshow-model-1.0.0.0-20190126.150709-41-sources.jar: com/mini/mshow/model/dbto/site/SubjectActivityDbto.java <==
package com.mini.mshow.model.dbto.site;

import java.util.Date;

import com.mini.framework.model.dbto.style1.DbtoIntEntity;
import com.mini.framework.model.role.write.Insertable;
import com.mini.framework.model.role.write.Updatable;
import com.mini.mshow.model.dbto.able.HaveActivity;
import com.mini.mshow.model.dbto.able.HaveAuthor;
import com.mini.mshow.model.dbto.able.IsOneSubject;
import com.mini.mshow.model.dto.multi.MultiFactory;
import com.mini.mshow.model.type.SubjectType;

public class SubjectActivityDbto extends DbtoIntEntity implements HaveActivity,HaveAuthor,IsOneSubject{

	/**
	 * 
	 */
	private static final long serialVersionUID = 6149160031081726843L;

	
	public SubjectOverviewDbto tryFindOverview(){
		boolean right = MultiFactory.validate(mutliContent);
		if(right){
			SubjectOverviewDbto overview = SubjectOverviewDbto.findOverview(MultiFactory.fromJson(mutliContent),200);
			overview.setTitle(title);
			overview.setSubTitle(subTitle);
			// TODO 如果活动有封面应该弄去上
			return overview;
		}
		return null;
	}
	
	public void fillFixField(SubjectOverviewDbto overview){
		if(overview!=null){
			overview.setSubjectAuthorId(authorId);
			overview.setSubjectId(getId());
			overview.setSubjectType(SubjectType.activity);
		}
	}
	
	
	/**
	 * 标题
	 */
	@Insertable(require="活动标题",minLength=2,maxLength=30)
	@Updatable(suffice="活动标题",minLength=2,maxLength=30)
	private String title;

	/**
	 * 活动子标题
	 */
	@Updatable(suffice="活动子标题",minLength=5)
	private String subTitle;

	/**
	 * 复杂的内容
	 */
	@Insertable(require="活动多媒体")
	@Updatable(suffice="活动多媒体")
	private String mutliContent;
	
	/**
	 * 作者的用户 id
	 */
	@Insertable(require="活动作者")
	@Updatable(forbid="活动作者")
	private Integer authorId;
	
	
	/**
	 * 原创的key，标记这个东西是谁
	 * 这个东西用于在复制的时候记录是谁原创的
	 */
	@Insertable(require="原始作者")
	@Updatable(forbid="原始作者")
	private Integer originalAuthorId;
	
	
	/**
	 * 开始时间
	 */
	@Insertable(require="开始时间")
	@Updatable(suffice="开始时间")
	private Date beginDate;
	

	/**
	 * 结束时间
	 */
	@Insertable(require="结束时间")
	@Updatable(suffice="结束时间")
	private Date endDate;
	
	
	/**
	 * 地址名字
	 */
	@Insertable(require="地址名字")
	@Updatable(suffice="地址名字")
	private String addressName;
	

	/**
	 * 地址GPS
	 * 用户短横线隔开
	 * 经度-纬度
	 */
	@Updatable(suffice="地址GPS")
	private String addressGps;
	
	
	/**
	 * 主办方
	 */
	@Insertable(require="主办方")
	@Updatable(suffice="主办方")
	private String presider;
	
	
	public String getTitle() {
		return title;
	}

	public void setTitle(String title) {
		this.title = title;
	}

	public String getMutliContent() {
		return mutliContent;
	}

	public void setMutliContent(String mutliContent) {
		this.mutliContent = mutliContent;
	}

	public String getSubTitle() {
		return subTitle;
	}

	public void setSubTitle(String subTitle) {
		this.subTitle = subTitle;
	}

	public Integer getAuthorId() {
		return authorId;
	}

	public void setAuthorId(Integer authorId) {
		this.authorId = authorId;
	}


	public Integer getOriginalAuthorId() {
		return originalAuthorId;
	}


	public void setOriginalAuthorId(Integer originalAuthorId) {
		this.originalAuthorId = originalAuthorId;
	}
	
	

	public Date getBeginDate() {
		return beginDate;
	}

	public void setBeginDate(Date beginDate) {
		this.beginDate = beginDate;
	}

	public Date getEndDate() {
		return endDate;
	}

	public void setEndDate(Date endDate) {
		this.endDate = endDate;
	}

	public String getAddressName() {
		return addressName;
	}

	public void setAddressName(String addressName) {
		this.addressName = addressName;
	}

	public String getAddressGps() {
		return addressGps;
	}

	public void setAddressGps(String addressGps) {
		this.addressGps = addressGps;
	}

	public String getPresider() {
		return presider;
	}

	public void setPresider(String presider) {
		this.presider = presider;
	}

	@Override
	public Integer showActivityId() {
		return getId();
	}

	@Override
	public Integer showAuthorId() {
		return authorId;
	}

	@Override
	public SubjectType showSubectType() {
		return SubjectType.activity;
	}

	@Override
	public Integer showSubjectId() {
		return getId();
	}
	

}
